@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 sub new {
 	my ($class, %data) = @_;
@@ -66,54 +66,63 @@ sub rss {
 
 	# itunes specs: http://www.apple.com/itunes/podcasts/specs.html
 	my $xml = '';
-	$xml .= qq{<?xml version="1.0" encoding="UTF-8"?>};
+	$xml .= qq{<?xml version="1.0" encoding="UTF-8"?>\n};
 	$xml .= qq{<rss xmlns:itunes="http://www.itunes.com/dtds/podcast-1.0.dtd" version="2.0">\n};
 	$xml .= qq{<channel>\n};
 	$xml .= qq{  <title>$self->{title}</title>\n};
 	$xml .= qq{  <link>$url/</link>\n};
+	$xml .= qq{  <pubDate>$self->{updated} GMT</pubDate>\n};
+	$xml .= qq{  <description>$self->{description}</description>\n};
 	$xml .= qq{  <language>$self->{language}</language>\n};
 	$xml .= qq{  <copyright>$self->{copyright}</copyright>\n};
-	$xml .= qq{  <description>$self->{description}</description>\n};
 
 	$xml .= qq{  <itunes:subtitle>$self->{subtitle}</itunes:subtitle>\n};
 	$xml .= qq{  <itunes:author>$self->{author}</itunes:author>\n};
 	$xml .= qq{  <itunes:summary>$self->{summary}</itunes:summary>\n};
+	if ($self->{image}) {
+		$xml .= qq{  <itunes:image href="$self->{image}" />\n};
+	}
+	if ($self->{keywords}) {
+		my $keywords = join ', ', @{ $self->{keywords} };
+		$xml .= qq{  <itunes:keywords>$keywords</itunes:keywords>\n};
+	}
 	$xml .= qq{  <itunes:owner>\n};
 	$xml .= qq{    <itunes:name>$self->{itunes_name}</itunes:name>\n};
 	$xml .= qq{    <itunes:email>$self->{itunes_email}</itunes:email>\n};
 	$xml .= qq{  </itunes:owner>\n};
-#	$xml .= qq{  <itunes:image href="http://example.com/podcasts/everything/AllAboutEverything.jpg" />};
-	$xml .= qq{  <itunes:category text="Technology" />\n};
+    $xml .= qq{  <itunes:explicit>no</itunes:explicit>\n};
+	$xml .= qq{  <itunes:category text="$self->{category}" />\n};
 
 	foreach my $e (@{ $self->{entries} }) {
 		$xml .= qq{  <item>\n};
 		$xml .= qq{    <title>$e->{title}</title>\n};
+		$xml .= qq{    <link rel="alternate" type="text/html" href="$e->{link}" />\n};
+		$xml .= qq{    <guid>$e->{link}</guid>\n};
 
+		$xml .= qq{    <description type="html">$e->{summary}</description>\n};
+#		$xml .= qq{    <updated>$e->{updated}Z</updated>\n};
 
-		if ($e->{itunes}) {
-			$xml .= qq{    <itunes:author>$e->{itunes}{author}</itunes:author>};
-#			$xml .= qq{    <itunes:subtitle></itunes:subtitle>\n};
-			$xml .= qq{    <itunes:summary>$e->{itunes}{summary}</itunes:summary>\n};
-#			$xml .= qq{    <itunes:image href="http://example.com/podcasts/everything/AllAboutEverything/Episode1.jpg" />\n};
-			$xml .= qq{    <enclosure url="$e->{enclosure}{url}" length="$e->{enclosure}{length}" type="$e->{enclosure}{type}" />};
-			$xml .= qq{    <pubDate>$e->{updated} GMT</pubDate>\n};
-			$xml .= qq{    <itunes:duration>e->{itunes}{duration}</itunes:duration>\n};
-		}
-
-
-		$xml .= qq{  <description type="html">$e->{summary}</description>\n};
-#		$xml .= qq{  <updated>$e->{updated}Z</updated>\n};
-		$xml .= qq{  <guid>$e->{link}</guid>\n};
-		$xml .= qq{  <link rel="alternate" type="text/html" href="$e->{link}" />};
-
-#		$xml .= qq{  <id>$e->{id}</id>\n};
-#		$xml .= qq{  <content type="html">$e->{content}</content>\n};
-#		if ($e->{author}) {
+#		$xml .= qq{    <id>$e->{id}</id>\n};
+#		$xml .= qq{    <content type="html">$e->{content}</content>\n};
+		if ($e->{author}) {
+			$xml .= qq{    <author>$e->{author}{name}</author>\n};
 #			$xml .= qq{    <author>\n};
 #			$xml .= qq{      <name>$e->{author}{name}</name>\n};
 #			$xml .= qq{      <email>$e->{author}{email}</email>\n};
 #			$xml .= qq{    </author>\n};
-#		}
+		}
+
+		if ($e->{itunes}) {
+			$xml .= qq{    <pubDate>$e->{updated} GMT</pubDate>\n};
+			$xml .= qq{    <itunes:author>$e->{itunes}{author}</itunes:author>\n};
+#			$xml .= qq{    <itunes:subtitle></itunes:subtitle>\n};
+			$xml .= qq{    <itunes:summary>$e->{itunes}{summary}</itunes:summary>\n};
+#			$xml .= qq{    <itunes:image href="http://example.com/podcasts/everything/AllAboutEverything/Episode1.jpg" />\n};
+			$xml .= qq{    <enclosure url="$e->{enclosure}{url}" length="$e->{enclosure}{length}" type="$e->{enclosure}{type}" />\n};
+			$xml .= qq{    <itunes:duration>$e->{itunes}{duration}</itunes:duration>\n};
+		}
+
+
 		$xml .= qq{  </item>\n};
 	}
 
